==> bonita-server-7.2.4-sources.jar: org/bonitasoft/engine/tracking/Record.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.tracking;

public class Record {

    private final long timestamp;

    private final TimeTrackerRecords name;

    private final String description;

    private final long duration;

    public Record(long timestamp, TimeTrackerRecords name, String description, long duration) {
        super();
        this.timestamp = timestamp;
        this.name = name;
        this.description = description;
        this.duration = duration;
    }

    public long getTimestamp() {
        return timestamp;
    }

    public TimeTrackerRecords getName() {
        return name;
    }

    public String getDescription() {
        return description;
    }

    public long getDuration() {
        return duration;
    }

}

==> bonita-server-7.9.4-sources.jar: org/bonitasoft/engine/tracking/Record.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.tracking;

public class Record {

    private final long timestamp;

    private final TimeTrackerRecords name;

    private final String description;

    private final long duration;

    public Record(final long timestamp, final TimeTrackerRecords name, final String description, final long duration) {
        super();
        this.timestamp = timestamp;
        this.name = name;
        this.description = description;
        this.duration = duration;
    }

    public long getTimestamp() {
        return this.timestamp;
    }

    public TimeTrackerRecords getName() {
        return this.name;
    }

    public String getDescription() {
        return this.description;
    }

    public long getDuration() {
        return this.duration;
    }

}
